@@ -9,8 +9,7 @@ class OCPProjectIndex(SearchIndex):
         ('name', 100),
         ('description', 100),
         ('display_name', 100),
-        ('owner', 100),
-        ('contact', 100),
+        ('project_owner', 100),
         ('customer', 100),
         ('docu_url', 100),
         ('workload', 100),
