@@ -1,8 +1,11 @@
+from django.contrib.contenttypes.models import ContentType
 from django.db.models import Sum, FloatField, IntegerField, DecimalField
 from django.db.models.functions import Cast
 
 from decimal import Decimal
 
+from django.shortcuts import get_object_or_404
+
 from netbox import settings
 from netbox.views.generic import ObjectView, ObjectListView, ObjectEditView, ObjectDeleteView, BulkImportView, \
     BulkEditView, BulkDeleteView
